==> mktcenter-service-threetree-1.0-20250915.094325-10-sources.jar: com/bizvane/mktcenterservice/rpc/cert/MktActivityCertificationFeignRpc.java <==
package com.bizvane.mktcenterservice.rpc.cert;

import com.bizvane.mktcenterservice.models.vo.tree3.reqvo.MktActivityCertificationRecordVo;
import com.bizvane.mktcenterservice.models.vo.tree3.reqvo.SelectPageActivityCertificationReqVO;
import com.bizvane.mktcenterservice.models.vo.tree3.respvo.GetDetailActivityCertificationRespVO;
import com.bizvane.mktcenterservice.models.vo.tree3.respvo.SelectPageActivityCertificationRespVO;
import com.bizvane.mktcenterservice.models.vo.tree3.respvo.SelectPageCertificationTypeRespVO;
import com.bizvane.utils.responseinfo.PageInfo;
import com.bizvane.utils.responseinfo.ResponseData;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.Map;

@ApiModel(value = "认证活动远程调用接口")
@FeignClient(value = "${feign.client.mktcenter.name}",path = "${feign.client.mktcenter.path}/mktActivityCertificationRpc")
public interface MktActivityCertificationFeignRpc {

    @ApiOperation(value = "认证类型列表查询")
    @PostMapping("/getCertificationTypePage")
    ResponseData<PageInfo<SelectPageCertificationTypeRespVO>> getCertificationTypePage(@RequestBody SelectPageActivityCertificationReqVO reqVO);


    @ApiOperation(value = "认证活动列表查询")
    @PostMapping("/getMktCertificationPage")
    ResponseData<PageInfo<SelectPageActivityCertificationRespVO>> getConstructabilityPage(@RequestBody SelectPageActivityCertificationReqVO reqVO);


    @ApiOperation(value = "认证活动详情查询")
    @GetMapping("/getMktCertificationDetail")
    ResponseData<GetDetailActivityCertificationRespVO> getMktCertificationDetail(@RequestParam Long mktActivityCertificationId,@RequestParam String memberCode,@RequestParam Long sysCompanyId,@RequestParam Long sysBrandId);

    @ApiOperation(value = "OCR识别身份证信息")
    @PostMapping("/ocrIdCard")
    ResponseData<Map<String,Object>> ocrIdCard(@RequestParam String portraitUrl, @RequestParam String nationalUrl);


    @ApiOperation(value = "认证活动保存、修改报名信息")
    @GetMapping("/saveOrModifyMktCertificationRecord")
    ResponseData<Boolean> saveOrModifyMktCertificationRecord(@RequestBody MktActivityCertificationRecordVo reqVO);


    @ApiOperation(value = "认证活动签到")
    @PostMapping("/signInMktCertification")
    ResponseData<Boolean> signInMktCertification(@RequestParam Long mktActivityCertificationRecordId,@RequestParam String memberCode,@RequestParam Long sysCompanyId,@RequestParam Long sysBrandId);








}

==> mktcenter-service-threetree-1.0-20250915.094531-11-sources.jar: com/bizvane/mktcenterservice/rpc/cert/MktActivityCertificationFeignRpc.java <==
package com.bizvane.mktcenterservice.rpc.cert;

import com.bizvane.mktcenterservice.models.vo.tree3.reqvo.MktActivityCertificationRecordVo;
import com.bizvane.mktcenterservice.models.vo.tree3.reqvo.SelectPageActivityCertificationReqVO;
import com.bizvane.mktcenterservice.models.vo.tree3.respvo.GetDetailActivityCertificationRespVO;
import com.bizvane.mktcenterservice.models.vo.tree3.respvo.SelectPageActivityCertificationRespVO;
import com.bizvane.mktcenterservice.models.vo.tree3.respvo.SelectPageCertificationTypeRespVO;
import com.bizvane.utils.responseinfo.PageInfo;
import com.bizvane.utils.responseinfo.ResponseData;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.Map;

@ApiModel(value = "认证活动远程调用接口")
@FeignClient(value = "${feign.client.mktcenter.name}",path = "${feign.client.mktcenter.path}/mktActivityCertificationRpc")
public interface MktActivityCertificationFeignRpc {

    @ApiOperation(value = "认证类型列表查询")
    @PostMapping("/getCertificationTypePage")
    ResponseData<PageInfo<SelectPageCertificationTypeRespVO>> getCertificationTypePage(@RequestBody SelectPageActivityCertificationReqVO reqVO);


    @ApiOperation(value = "认证活动列表查询")
    @PostMapping("/getMktCertificationPage")
    ResponseData<PageInfo<SelectPageActivityCertificationRespVO>> getConstructabilityPage(@RequestBody SelectPageActivityCertificationReqVO reqVO);


    @ApiOperation(value = "认证活动详情查询")
    @PostMapping("/getMktCertificationDetail")
    ResponseData<GetDetailActivityCertificationRespVO> getMktCertificationDetail(@RequestParam Long mktActivityCertificationId,@RequestParam String memberCode,@RequestParam Long sysCompanyId,@RequestParam Long sysBrandId);

    @ApiOperation(value = "OCR识别身份证信息")
    @PostMapping("/ocrIdCard")
    ResponseData<Map<String,Object>> ocrIdCard(@RequestParam String portraitUrl, @RequestParam String nationalUrl);


    @ApiOperation(value = "认证活动保存、修改报名信息")
    @PostMapping("/saveOrModifyMktCertificationRecord")
    ResponseData<Boolean> saveOrModifyMktCertificationRecord(@RequestBody MktActivityCertificationRecordVo reqVO);


    @ApiOperation(value = "认证活动签到")
    @PostMapping("/signInMktCertification")
    ResponseData<Boolean> signInMktCertification(@RequestParam Long mktActivityCertificationRecordId,@RequestParam String memberCode,@RequestParam Long sysCompanyId,@RequestParam Long sysBrandId);








}
